/*
 * Copyright 2010 Trustees of the University of Pennsylvania Licensed under the
 * Educational Community License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 *
 * http://www.osedu.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package metridoc.plugins.grid

import org.apache.camel.Exchange
import groovy.sql.GroovyRowResult

/**
 * Created by IntelliJ IDEA.
 * User: tbarker
 * Date: 9/7/11
 * Time: 3:11 PM
 *
 * Represents an {@link Iterator} of {@link Map} where the keys are meant to be column headers of the Grid that was
 * created.
 *
 */
public interface Grid extends Iterator<GroovyRowResult>{
    /**
     *
     * @return an ordered set of columns, columns names should always be unique for a grid
     */
    Set<String> getColumns()
    /**
     * @return the original {@link Exchange} that was used to create the {@link Grid}.  This value can never be null
     */
    Exchange getOriginalExchange()
    /**
     *
     * @return current line of the grid
     */
    int getLine()
}