/*
 * Copyright 2010 Trustees of the University of Pennsylvania Licensed under the
 * Educational Community License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 *
 * http://www.osedu.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package metridoc.plugins.grid.definitions

import org.apache.camel.model.ProcessorDefinition
import org.apache.camel.Processor
import org.apache.camel.spi.RouteContext
import org.apache.camel.processor.UnitOfWorkProcessor

/**
 * Created by IntelliJ IDEA.
 * User: tbarker
 * Date: 9/8/11
 * Time: 1:59 PM
 * To change this template use File | Settings | File Templates.
 */
class GridDefinition extends PropertyDefinition<GridDefinition> {

    private List<ProcessorDefinition> outputs = new ArrayList<ProcessorDefinition>();
    String type
    Closure filter
    Closure parser

    GridDefinition grid(String type) {
        this.type = type
        return this
    }

    GridDefinition withFilter(Closure closure) {
        this.filter = closure
        return this
    }

    GridDefinition withParser(Closure closure) {
        this.parser = closure
        return this
    }

    @Override
    boolean isOutputSupported() {
        return true;
    }

    @Override
    Processor createProcessor(RouteContext routeContext) {
        Processor next = this.createChildProcessor(routeContext, true);
        // wrap the hand off with a unit of work
        next = new UnitOfWorkProcessor(routeContext, next);
        return new GridProcessor(next: next, type: type, filter: filter, parser: parser, properties: properties)
    }

    @Override
    String getShortName() {
        return getLabel()
    }

    @Override
    String getLabel() {
        return "grid(${type})"
    }

    public List<ProcessorDefinition> getOutputs() {
        return outputs;
    }

    public void setOutputs(List<ProcessorDefinition> outputs) {
        this.outputs = outputs;
    }

    public String toString() {
        return "GridDefinition[" +
                "outputs=" + outputs +
                ", type='" + type + '\'' +
                ", filter=" + filter +
                ", transformation=" + parser +
                ", properties=" + properties +
                ']';
    }
}
