/*
 * Copyright 2010 Trustees of the University of Pennsylvania Licensed under the
 * Educational Community License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 *
 * http://www.osedu.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package metridoc.plugins.impl.grid

import java.sql.ResultSet
import metridoc.plugins.grid.DefaultGridCreator
import metridoc.plugins.grid.Grid
import metridoc.utils.Assert
import org.apache.camel.Exchange
import groovy.sql.GroovyRowResult
import metridoc.plugins.Plugin

/**
 * Created by IntelliJ IDEA.
 * User: tbarker
 * Date: 9/27/11
 * Time: 8:53 AM
 */
@Plugin(category = "grid", name = "sql")
class SqlGrid extends DefaultGridCreator {

    ResultSet resultSet
    GroovyRowResult next

    @Override
    Grid doCreate(Exchange exchange) {
        def resultSet = exchange.in.getBody(ResultSet.class)
        Assert.notNull(resultSet, "exchange must contain a ResultSet to crete an SqlGrid")
        return new SqlGrid(resultSet: resultSet)
    }

    @Override
    boolean doHasNext() {
        if(next) {
            return true
        }

        loadNext()

        return next != null
    }

    void loadNext() {
        boolean hasNext = resultSet.next()

        if(hasNext) {
            next = resultSet.toRowResult()
        } else {
            next = null
        }
    }

    @Override
    GroovyRowResult doNext() {
        if(next == null) {
            loadNext()
        }
        def result = next
        next = null

        return result
    }
}
